Coverage for C:\src\imod-python\imod\mf6\__init__.py: 100%

1"""

2 Create a Modflow 6 model.

3"""

4

5 from imod.mf6.adv import AdvectionCentral, AdvectionTVD, AdvectionUpstream

6 from imod.mf6.api_package import ApiPackage

7 from imod.mf6.buy import Buoyancy

8 from imod.mf6.chd import ConstantHead

9 from imod.mf6.cnc import ConstantConcentration

10 from imod.mf6.dis import StructuredDiscretization

11 from imod.mf6.disv import VerticesDiscretization

12 from imod.mf6.drn import Drainage

13 from imod.mf6.dsp import Dispersion

14 from imod.mf6.evt import Evapotranspiration

15 from imod.mf6.ghb import GeneralHeadBoundary

16 from imod.mf6.gwfgwf import GWFGWF

17 from imod.mf6.gwfgwt import GWFGWT

18 from imod.mf6.gwtgwt import GWTGWT

19 from imod.mf6.hfb import (

20 HorizontalFlowBarrierBase,

21 HorizontalFlowBarrierHydraulicCharacteristic,

22 HorizontalFlowBarrierMultiplier,

23 HorizontalFlowBarrierResistance,

24 LayeredHorizontalFlowBarrierHydraulicCharacteristic,

25 LayeredHorizontalFlowBarrierMultiplier,

26 LayeredHorizontalFlowBarrierResistance,

27)

28 from imod.mf6.ic import InitialConditions

29 from imod.mf6.ims import (

30 Solution,

31 SolutionPresetComplex,

32 SolutionPresetModerate,

33 SolutionPresetSimple,

34)

35 from imod.mf6.ist import ImmobileStorageTransfer

36 from imod.mf6.lak import Lake, LakeData, OutletManning, OutletSpecified, OutletWeir

37 from imod.mf6.model_gwf import GroundwaterFlowModel

38 from imod.mf6.model_gwt import GroundwaterTransportModel

39 from imod.mf6.mst import MobileStorageTransfer

40 from imod.mf6.npf import NodePropertyFlow

41 from imod.mf6.oc import OutputControl

42 from imod.mf6.out import open_cbc, open_conc, open_hds, read_cbc_headers, read_grb

43 from imod.mf6.rch import Recharge

44 from imod.mf6.riv import River

45 from imod.mf6.simulation import Modflow6Simulation

46 from imod.mf6.src import MassSourceLoading

47 from imod.mf6.ssm import SourceSinkMixing

48 from imod.mf6.sto import SpecificStorage, Storage, StorageCoefficient

49 from imod.mf6.timedis import TimeDiscretization

50 from imod.mf6.utilities.regrid import RegridderType, RegridderWeightsCache

51 from imod.mf6.uzf import UnsaturatedZoneFlow

52 from imod.mf6.wel import Well, WellDisStructured, WellDisVertices

53 from imod.mf6.write_context import WriteContext